import type { TokenCollection, UserType, TokenType, TokenValidationDetailsType } from './types.js';
import { type SessionManager } from '../session-managers/index.js';
/**
 * Saves the provided token to the current session.
 * @param {SessionManager} sessionManager
 * @param {string} token
 * @param {TokenType} type
 */
export declare const commitTokenToSession: (sessionManager: SessionManager, token: string, type: TokenType, validationDetails: TokenValidationDetailsType) => Promise<void>;
/**
 * Saves the access, refresh and id tokens provided in the `TokenCollection`
 * object to the current session.
 * @param {SessionManager} sessionManager
 * @param tokens
 */
export declare const commitTokensToSession: (sessionManager: SessionManager, tokens: TokenCollection, validationDetails: TokenValidationDetailsType) => Promise<void>;
/**
 * Extracts the refresh token from current session returns null if the
 * token is not found.
 * @param {SessionManager} sessionManager
 * @returns {string | null}
 */
export declare const getRefreshToken: (sessionManager: SessionManager) => Promise<string | null>;
/**
 * Extracts the access token from current session returns null if the
 * token is not found.
 * @param {SessionManager} sessionManager
 * @returns {string | null}
 */
export declare const getAccessToken: (sessionManager: SessionManager) => Promise<string | null>;
/**
 * Extracts the user information from the current session returns null if
 * the token is not found.
 * @param {SessionManager} sessionManager
 * @returns {string | null}
 */
export declare const getUserFromSession: (sessionManager: SessionManager, validationDetails: TokenValidationDetailsType) => Promise<UserType | null>;
/**
 * Checks if the provided JWT token is valid (expired or not).
 * @param {string | null} token
 * @returns {boolean} is expired or not
 */
export declare const isTokenExpired: (token: string | null, validationDetails: TokenValidationDetailsType) => Promise<boolean>;
